==> apache-pinot-1.0.0-src.tar.gz: apache-pinot-1.0.0-src/pinot-plugins/pinot-file-system/pinot-s3/src/test/java/org/apache/pinot/plugin/filesystem/S3ConfigTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.plugin.filesystem;

import org.apache.pinot.spi.env.PinotConfiguration;
import org.testng.Assert;
import org.testng.annotations.Test;


public class S3ConfigTest {
  @Test
  public void testGetHttpClientBuilder() {
    PinotConfiguration pinotConfig = new PinotConfiguration();
    S3Config cfg = new S3Config(pinotConfig);
    Assert.assertNull(cfg.getHttpClientBuilder());

    pinotConfig.setProperty("httpclient.maxConnections", 100);
    pinotConfig.setProperty("httpclient.socketTimeout", "PT1M10S");
    pinotConfig.setProperty("httpclient.connectionTimeout", "PT2M20S");
    pinotConfig.setProperty("httpclient.connectionTimeToLive", "3m30s");
    pinotConfig.setProperty("httpclient.connectionAcquisitionTimeout", "4m40s");
    cfg = new S3Config(pinotConfig);
    Assert.assertNotNull(cfg.getHttpClientBuilder());
  }

  @Test(expectedExceptions = IllegalArgumentException.class)
  public void testParseDuration() {
    Assert.assertEquals(S3Config.parseDuration("P1DT2H30S"), S3Config.parseDuration("1d2h30s"));
    S3Config.parseDuration("10");
  }
}

==> apache-pinot-1.4.0-src.tar.gz: apache-pinot-1.4.0-src/pinot-plugins/pinot-file-system/pinot-s3/src/test/java/org/apache/pinot/plugin/filesystem/S3ConfigTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.plugin.filesystem;

import org.apache.pinot.spi.env.PinotConfiguration;
import org.testng.Assert;
import org.testng.annotations.Test;
import software.amazon.awssdk.services.s3.model.StorageClass;


public class S3ConfigTest {
  @Test
  public void testGetHttpClientBuilder() {
    PinotConfiguration pinotConfig = new PinotConfiguration();
    S3Config cfg = new S3Config(pinotConfig);
    Assert.assertNull(cfg.getHttpClientBuilder());

    pinotConfig.setProperty("httpclient.maxConnections", 100);
    pinotConfig.setProperty("httpclient.socketTimeout", "PT1M10S");
    pinotConfig.setProperty("httpclient.connectionTimeout", "PT2M20S");
    pinotConfig.setProperty("httpclient.connectionTimeToLive", "3m30s");
    pinotConfig.setProperty("httpclient.connectionAcquisitionTimeout", "4m40s");
    cfg = new S3Config(pinotConfig);
    Assert.assertNotNull(cfg.getHttpClientBuilder());
  }

  @Test(expectedExceptions = IllegalArgumentException.class)
  public void testParseDuration() {
    Assert.assertEquals(S3Config.parseDuration("P1DT2H30S"), S3Config.parseDuration("1d2h30s"));
    S3Config.parseDuration("10");
  }

  @Test
  public void testDefaultStorageClassIsNull() {
    PinotConfiguration pinotConfig = new PinotConfiguration();
    S3Config cfg = new S3Config(pinotConfig);
    Assert.assertNull(cfg.getStorageClass());
  }

  @Test
  public void testIntelligentTieringStorageClass() {
    PinotConfiguration pinotConfig = new PinotConfiguration();
    pinotConfig.setProperty("storageClass", StorageClass.INTELLIGENT_TIERING.toString());
    S3Config cfg = new S3Config(pinotConfig);
    Assert.assertEquals(cfg.getStorageClass(), "INTELLIGENT_TIERING");
  }

  @Test(expectedExceptions = IllegalStateException.class)
  public void testInvalidStorageClass() {
    PinotConfiguration pinotConfig = new PinotConfiguration();
    pinotConfig.setProperty("storageClass", "invalid-storage-class");
    S3Config cfg = new S3Config(pinotConfig);
  }

  @Test
  public void testLegacyMd5Plugin() {
    PinotConfiguration pinotConfig = new PinotConfiguration();
    pinotConfig.setProperty("useLegacyMd5Plugin", "true");
    S3Config cfg = new S3Config(pinotConfig);
    Assert.assertTrue(cfg.useLegacyMd5Plugin());
  }
}
